@@ -1,6 +1,6 @@
 from .installer import install_pyrosetta, check_pyrosetta, download_pyrosetta
 from .colab_ops import *  # has __all__
-if installer.check_pyrosetta():
+if check_pyrosetta():
     from .weights import WeightWatcher
     from .blueprint_maker import Blueprinter
     from .chain_ops import ChainOps, Transmogrifier, Murinizer
